API Documentation
-----------------
.. automodule:: luma.lcd
    :members:
    :undoc-members:
    :show-inheritance:

.. inheritance-diagram:: luma.core.device luma.core.mixin luma.core.virtual luma.lcd.device

Upgrading
"""""""""
.. warning::
   Version 2.0.0 was released on 2 June 2019: this came with the removal of the
   :py:class:`luma.lcd.aux.backlight` class. The equivalent functionality has now
   been subsumed into the device classes that have a backlight capability.

:mod:`luma.lcd.device`
""""""""""""""""""""""
.. automodule:: luma.lcd.device
    :members:
    :inherited-members:
    :undoc-members:
    :show-inheritance:
